--- homepage: true layout: product title: Decompress ZIP files while downloading them description: Use this Python package to unZIP all the files in a ZIP archive, without needing the entire archive in memory or disk at once. startButton: href: "get-started" text: Get started ---

## Memory

Only a small amount of the compressed or decompressed data is in memory at any one time.

## Encryption

Supports WinZIP-style AES-encryption, as well as legacy ZipCrypto/Zip 2.0.

## Large files

Decompresses Zip64 and Deflate64 ZIPs that are used for larger amounts of data.

## Contributions

The code for stream-unzip is public and contributions are welcome through the stream-unzip repository on GitHub.